pub struct Delete(/* private fields */);Expand description
delete and deleteid commands.
Implementations
Sourceimpl Delete
impl Delete
Sourcepub fn position(pos: SongPosition) -> Self
pub fn position(pos: SongPosition) -> Self
Remove the song at the given position from the queue.
Sourcepub fn range<R>(range: R) -> Selfwhere
R: RangeBounds<SongPosition>,
pub fn range<R>(range: R) -> Selfwhere
R: RangeBounds<SongPosition>,
Remove the given range from the queue.
The range must have at least a lower bound.