Tools for constructing filter expressions, as used by e.g. the find command.
Structs
Enums
- Operator
- Operators which can be used in filter expressions.
Tools for constructing filter expressions, as used by e.g. the find command.