Struct mpd_client::raw::RawCommandList [−][src]
pub struct RawCommandList { /* fields omitted */ }A non-empty list of commands.
Commands will be automatically wrapped in a proper command list if necessary.
Implementations
impl CommandList[src]
impl CommandList[src]pub fn new(first: Command) -> CommandList[src]
Create a command list from the given single command.
Unless further commands are added, the command will not be wrapped into a list.
pub fn command(self, command: Command) -> CommandList[src]
Add another command to the list.
Same as CommandList::add, but takes and returns self for chaining.
pub fn add(&mut self, command: Command)[src]
Add another command to the list.
pub fn len(&self) -> usize[src]
Get the number of commands in this command list.
This is never 0.