Module responses

Typed responses to individual commands.

Structs

AlbumArt
Response to the albumart and readpicture commands.
Count
Response to the Count command.
GroupedListValuesIter
Iterator over references to grouped values.
List
Response to the list command.
ListValuesIntoIter
Iterator over ungrouped List values.
ListValuesIter
Iterator over references to ungrouped List values.
Playlist
A stored playlist, as returned by listplaylists.
ReplayGainStatus
Response to the replay_gain_status command.
Song
A single song, as returned by the playlist or current song commands.
SongInQueue
A Song in the current queue, as returned by the playlistinfo command.
SongRange
Range used when playing only part of a Song.
Stats
Response to the stats command, containing general server statistics.
Status
Response to the status command.
StickerFind
Response to the sticker find command.
StickerGet
Response to the sticker get command.
StickerList
Response to the sticker list command.
Timestamp
A timestamp, used for modification times.
TypedResponseError
Error returned when failing to convert a raw Frame into the proper typed response.

Enums

PlayState
Possible playback states.