#[non_exhaustive]pub enum Tag {
Show 32 variants
Album,
AlbumArtist,
AlbumArtistSort,
AlbumSort,
Artist,
ArtistSort,
Comment,
Composer,
ComposerSort,
Conductor,
Date,
Disc,
Ensemble,
Genre,
Grouping,
Label,
Location,
Movement,
MovementNumber,
MusicBrainzArtistId,
MusicBrainzRecordingId,
MusicBrainzReleaseArtistId,
MusicBrainzReleaseId,
MusicBrainzTrackId,
MusicBrainzWorkId,
Name,
OriginalDate,
Performer,
Title,
Track,
Work,
Other(Box<str>),
}Expand description
Tags which can be set on a Song.
MusicBrainz tags are named differently from how they appear in the protocol to better reflect their actual purpose.
Tag validity
Manually constructing a tag with the Other variant may result in protocols errors if the
tag is invalid. Use the TryFrom implementation for checked conversion.
Unknown tags
When parsing or constructing responses, tags not recognized by this type will be stored as they
are encountered using the Other variant. Additionally the enum is marked as non-exhaustive,
so additional tags may be added without breaking compatibility.
The equality is checked using the string representation, so Other variants are
forward-compatible with new variants being added.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Album
AlbumArtist
AlbumArtistSort
AlbumSort
Artist
ArtistSort
Comment
Composer
ComposerSort
Conductor
Date
Disc
Ensemble
Genre
Grouping
Label
Location
Movement
MovementNumber
MusicBrainzArtistId
MusicBrainzRecordingId
MusicBrainzReleaseArtistId
MusicBrainzReleaseId
MusicBrainzTrackId
MusicBrainzWorkId
Name
OriginalDate
Performer
Title
Track
Work
Other(Box<str>)
Catch-all variant that contains the raw tag string when it doesn’t match any other variants, but is valid.